# -*- coding: utf-8 -*-
# stuhl.py

## Änderung der Attribute zu "privaten" und Einbau aller
## sondierenden und verändernden Methoden
## beispielhaft hier in der Klasse Stuhl

from grafikfenster import *
from math import radians

### ---------------------------------------------------
class Stuhl():
    """Klasse Stuhl
    ermoeglicht das Zeichnen und Bearbeiten eines
    Stuhl-Symbols fuer den Raumplaner"""
    
    def __init__(self, sichtbar=False):
        """einfacher Konstruktor"""
        self.__x=20
        self.__y=20
        self.__b=40
        self.__t=40
        self.__w=270
        self.__f="blue"
        self.__s=sichtbar
        if sichtbar: self.Zeige()
        
    def GibFigur(self):
        """definiert und transformiert die zu zeichnende Figur"""
        gc = Zeichenflaeche.GibZeichenflaeche().GibGC()
        path = gc.CreatePath()
        
        path.MoveToPoint(0, 0)
        path.AddLineToPoint(self.__b, 0)
        path.AddLineToPoint(self.__b*1.1, self.__t)
        path.AddLineToPoint(-self.__b*0.1, self.__t)
        path.AddLineToPoint(0, 0)
        path.AddLineToPoint(0, -self.__t*0.1)
        path.AddLineToPoint(self.__b, -self.__t*0.1)
        path.AddLineToPoint(self.__b, 0)
        
        gc.PushState()
        gc.Translate(self.__x+self.__b/2, self.__y+self.__t/2)
        gc.Rotate(radians(self.__w))
        gc.Translate(-self.__b/2, -self.__t/2)
        transformation = gc.GetTransform()
        gc.PopState()
        path.Transform(transformation)
        return path

    def GibX(self):
        """Get-Methode fuer die x-Position"""
        return self.__x
    
    def GibY(self):
        """Get-Methode fuer die y-Position"""
        return self.__y
    
    def GibBreite(self):
        """Get-Methode fuer die Breite"""
        return self.__b
    
    def GibTiefe(self):
        """Get-Methode fuer die Tiefe"""
        return self.__t
    
    def GibFarbe(self):
        """Get-Methode fuer die Farbe"""
        return self.__f
    
    def GibSichtbar(self):
        """Get-Methode fuer die Sichtbarkeit"""
        return self.__s

    def BewegeHorizontal(self, weite):
        """Veraendernde Methode fuer die x-Position"""
        self.Verberge()
        self.__x += weite
        self.Zeige()
    
    def BewegeVertikal(self, weite):
        """Veraendernde Methode fuer die y-Position"""
        self.Verberge()
        self.__y += weite
        self.Zeige()
    
    def Drehe(self, winkel):
        """Veraendernde Methode fuer die Orientierung [Winkel]"""
        self.Verberge()
        self.__w += winkel
        self.Zeige()

    def AendereFarbe(self, neueFarbe):
        """Veraendernde Methode fuer die Farbe"""
        self.Verberge()
        self.__f = neueFarbe
        self.Zeige()

    def Verberge(self):
        """Veraendernde Methode fuer die Sichtbarkeit mit Wert False"""
        self.__s = False
        Zeichenflaeche.GibZeichenflaeche().Entferne(self)

    def Zeige(self):
        """Veraendernde Methode fuer die Sichtbarkeit mit Wert True"""
        self.__s = True
        Zeichenflaeche.GibZeichenflaeche().Zeichne(self)

### ---------------------------------------------------
class StuhlApp(wx.App):
    """Test-Anwendung speziell fuer Stuhl"""
    def OnInit(self):
        self.__fenster = GrafikFenster(None, "Raumplaner-Grafik")
        self.SetTopWindow(self.__fenster)
        self.__fenster.Show(True)
        self.__fenster.panel.Refresh()
        self.__fenster.ZeigeShellFrame()
        #self.__fenster.ZeigeFillingFrame()
        self.TestAnwendung()
        return True

    def TestAnwendung(self):
        """Allein fuer die Testanwendung:"""
        global stuhl
        stuhl=Stuhl(True)

        
### ---------------------------------------------------
if __name__ == '__main__':
    app = StuhlApp(redirect=False)
    # Parameterwert True, wenn Ausgaben in der Standard E/A angezeigt werden sollen
    app.MainLoop()
