# -*- coding: utf-8 -*-
# tisch.py

from grafikfenster import *
from math import radians

### ---------------------------------------------------
class Tisch():
    """Klasse Tisch
    ermoeglicht das Zeichnen und Bearbeiten eines
    Tisch-Symbols fuer den Raumplaner"""

    def __init__(self, sichtbar=False):
        """einfacher Konstruktor"""
        self.__x=70
        self.__y=10
        self.__b=120
        self.__t=60
        self.__w=0
        self.__f='red'
        self.__s=sichtbar
        if sichtbar: self.Zeige()
        
    def GibFigur(self):
        """definiert und transformiert die zu zeichnende Figur"""
        gc = Zeichenflaeche.GibZeichenflaeche().GibGC()
        path = gc.CreatePath()
        
        path.AddRectangle(0, 0, self.__b, self.__t)
        
        gc.PushState()
        gc.Translate(self.__x+self.__b/2, self.__y+self.__t/2)
        gc.Rotate(radians(self.__w))
        gc.Translate(-self.__b/2, -self.__t/2)
        transformation = gc.GetTransform()
        gc.PopState()
        path.Transform(transformation)
        return path

    def GibX(self):
        """Get-Methode fuer die x-Position"""
        return self.__x
    
    def GibY(self):
        """Get-Methode fuer die y-Position"""
        return self.__y
    
    def GibBreite(self):
        """Get-Methode fuer die Breite"""
        return self.__b
    
    def GibTiefe(self):
        """Get-Methode fuer die Tiefe"""
        return self.__t
    
    def GibFarbe(self):
        """Get-Methode fuer die Farbe"""
        return self.__f
    
    def GibSichtbar(self):
        """Get-Methode fuer die Sichtbarkeit"""
        return self.__s

    def BewegeHorizontal(self, weite):
        """Veraendernde Methode fuer die x-Position"""
        self.Verberge()
        self.x += weite
        self.Zeige()
    
    def Bewege(self, xWeite, yWeite):
        """Veraendernde Methode fuer die x-Position und
        die y-Position"""
        self.Verberge()
        self.__x += weite
        self.Zeige()
    
    def BewegeVertikal(self, weite):
        """Veraendernde Methode fuer die y-Position"""
        self.Verberge()
        self.__y += weite
        self.Zeige()
    
    def Drehe(self, winkel):
        """Veraendernde Methode fuer die Orientierung [Winkel]"""
        self.Verberge()
        self.__w += winkel
        self.Zeige()

    def AendereFarbe(self, neueFarbe):
        """Veraendernde Methode fuer die Farbe"""
        self.Verberge()
        self.__f = neueFarbe
        self.Zeige()

    def Verberge(self):
        """Veraendernde Methode fuer die Sichtbarkeit mit Wert False"""
        self.__s = False
        Zeichenflaeche.GibZeichenflaeche().Entferne(self)

    def Zeige(self):
        """Veraendernde Methode fuer die Sichtbarkeit mit Wert True"""
        self.__s = True
        Zeichenflaeche.GibZeichenflaeche().Zeichne(self)

### ---------------------------------------------------
class TischApp(wx.App):
    """Test-Anwendung speziell fuer Tisch"""
    def OnInit(self):
        self.__fenster = GrafikFenster(None, "Raumplaner-Grafik")
        self.SetTopWindow(self.__fenster)
        self.__fenster.Show(True)
        self.__fenster.panel.Refresh()
        self.__fenster.ZeigeShellFrame()
        #self.__fenster.ZeigeFillingFrame()
        self.TestAnwendung()
        return True

    def TestAnwendung(self):
        """Allein fuer die Testanwendung:"""
        global tisch
        tisch=Tisch(True)
        
### ---------------------------------------------------
if __name__ == '__main__':
    app = TischApp(redirect=False)
    # Parameterwert True, wenn Ausgaben in der Standard E/A angezeigt werden sollen
    app.MainLoop()
